
#include <stdint.h>
#include <stdlib.h>

#include "GUI.h"
#include "stm32756g_eval_ts.h"

#include "sldr.h"
#include "colors.h"




void draw_slider_h(sldr_area_t *sldr_area)
{
    uint16_t y_off = ((sldr_area->y1 - sldr_area->y0) / 2) - 4;

    float step;
    
    float x0 = (float)(sldr_area->x0 + 12);
    float x1 = (float)(sldr_area->x1 - 12);
    
    char str[10];

    step = ((x1 - x0) / (float)sldr_area->scale);
   
    // clear previous pointer
    GUI_SetColor(UTIA_COLOR_GRAY_L);
    GUI_FillCircle((int)(x0 + ((float)sldr_area->pos_prev * step)) , sldr_area->y0 + y_off + 5, 12);
    
    // do external update
    //sldr_area->pos_prev = sldr_area->pos;
    
    // fill the line
    GUI_SetColor(GUI_LIGHTGRAY);
    GUI_FillRoundedFrame(sldr_area->x0 + 12, sldr_area->y0 + y_off, sldr_area->x1 - 12, sldr_area->y0 + y_off + 9, 5, 3);

    // line border
    GUI_SetColor(GUI_GRAY);
    GUI_DrawRoundedFrame(sldr_area->x0 + 12, sldr_area->y0 + y_off, sldr_area->x1 - 12, sldr_area->y0 + y_off + 9, 5, 3);

    // new pointer
    GUI_SetColor(GUI_DARKGRAY);   
    GUI_FillCircle((int)(x0 + ((float)sldr_area->pos * step)) , sldr_area->y0 + y_off + 5, 12);

    // print actual position
    GUI_SetColor(UTIA_COLOR_BLUE2);
    GUI_SetBkColor(UTIA_COLOR_GRAY_L);
    GUI_SetFont(&GUI_Font20B_ASCII);
    sprintf(str, "%d/%d   ", sldr_area->pos, sldr_area->scale);
    GUI_DispStringAt(str, sldr_area->x1 + 6, sldr_area->y0 + y_off - 4);

}


void draw_slider_v(sldr_area_t *sldr_area)
{
    uint16_t x_off = ((sldr_area->x1 - sldr_area->x0) / 2) - 4;

    float step;
    
    float y0 = (float)(sldr_area->y0 + 12);
    float y1 = (float)(sldr_area->y1 - 12);
    
    char str[10];
    
    step = ((y1 - y0) / (float)sldr_area->scale);
   
    // clear previous pointer
    GUI_SetColor(UTIA_COLOR_GRAY_L);
    GUI_FillCircle(sldr_area->x0 + x_off + 5, (int)(y0 + ((float)sldr_area->pos_prev * step)), 12);

    // do external update
    //sldr_area->pos_prev = sldr_area->pos;
    
    // fill the line
    GUI_SetColor(GUI_LIGHTGRAY);
    GUI_FillRoundedFrame(sldr_area->x0 + x_off, sldr_area->y0 + 12, sldr_area->x0 + x_off + 9, sldr_area->y1 - 12, 5, 3);

    // line border
    GUI_SetColor(GUI_GRAY);
    GUI_DrawRoundedFrame(sldr_area->x0 + x_off, sldr_area->y0 + 12, sldr_area->x0 + x_off + 9, sldr_area->y1 - 12, 5, 3);

    // new pointer
    GUI_SetColor(GUI_DARKGRAY);   
    GUI_FillCircle(sldr_area->x0 + x_off + 5, (int)(y0 + ((float)sldr_area->pos * step)), 12);

    // print actual position
    GUI_SetColor(UTIA_COLOR_BLUE2);
    GUI_SetBkColor(UTIA_COLOR_GRAY_L);
    GUI_SetFont(&GUI_Font20B_ASCII);
    sprintf(str, " %d/%d  ", sldr_area->pos, sldr_area->scale);
    GUI_DispStringHCenterAt(str, sldr_area->x0 + x_off + 10, sldr_area->y1 + 6);

}


uint32_t get_slider_h(TS_StateTypeDef *touch_state, sldr_area_t *sldr_area, uint8_t sldr_cnt)
{
    uint8_t   i;
    
    float step;   
    float x0;
    float x1;
    float pos;

    for (i = 0; i < sldr_cnt; i++) {

        if ( (touch_state->x > sldr_area[i].x0) && (touch_state->x < sldr_area[i].x1) &&
             (touch_state->y > sldr_area[i].y0) && (touch_state->y < sldr_area[i].y1)
           ) {
         
              x0 = (float)(sldr_area[i].x0 + 12);
              x1 = (float)(sldr_area[i].x1 - 12);
              step = (x1 - x0) / (float)sldr_area[i].scale;
              
              pos = ((float)touch_state->x - (float)sldr_area[i].x0) / step;

              if (pos > (float)sldr_area[i].scale)
                  pos = (float)sldr_area[i].scale;

              if (pos < 0.0f)
                  pos = 0.0f;

              sldr_area[i].pos = (uint16_t)pos;
                            
              return (1 << i);
        }
    }
    return 0;
}

uint32_t get_slider_v(TS_StateTypeDef *touch_state, sldr_area_t *sldr_area, uint8_t sldr_cnt)
{
    uint8_t   i;
    
    float step;   
    float y0;
    float y1;
    float pos;

    for (i = 0; i < sldr_cnt; i++) {

        if ( (touch_state->x > sldr_area[i].x0) && (touch_state->x < sldr_area[i].x1) &&
             (touch_state->y > sldr_area[i].y0) && (touch_state->y < sldr_area[i].y1)
           ) {
         
              y0 = (float)(sldr_area[i].y0 + 12);
              y1 = (float)(sldr_area[i].y1 - 12);
              step = (y1 - y0) / (float)sldr_area[i].scale;
              
              pos = ((float)touch_state->y - (float)sldr_area[i].y0) / step;

              if (pos > (float)sldr_area[i].scale)
                  pos = (float)sldr_area[i].scale;

              if (pos < 0.0f)
                  pos = 0.0f;

              sldr_area[i].pos = (uint16_t)pos;
                            
              return (1 << i);
        }
    }
    return 0;
}










